OnboardMessage

Enum OnboardMessage 

pub enum OnboardMessage {
    CreateSession {
        requester: InstanceId,
        session_id: SessionId,
        sequence_hashes: Vec<SequenceHash>,
    },
    SearchComplete {
        responder: InstanceId,
        session_id: SessionId,
    },
    G2Results {
        responder: InstanceId,
        session_id: SessionId,
        sequence_hashes: Vec<SequenceHash>,
        block_ids: Vec<BlockId>,
    },
    G3Results {
        responder: InstanceId,
        session_id: SessionId,
        sequence_hashes: Vec<SequenceHash>,
    },
    HoldBlocks {
        requester: InstanceId,
        session_id: SessionId,
        hold_hashes: Vec<SequenceHash>,
        drop_hashes: Vec<SequenceHash>,
    },
    StageBlocks {
        requester: InstanceId,
        session_id: SessionId,
        stage_hashes: Vec<SequenceHash>,
    },
    BlocksReady {
        responder: InstanceId,
        session_id: SessionId,
        sequence_hashes: Vec<SequenceHash>,
        block_ids: Vec<BlockId>,
    },
    Acknowledged {
        responder: InstanceId,
        session_id: SessionId,
    },
    ReleaseBlocks {
        requester: InstanceId,
        session_id: SessionId,
        release_hashes: Vec<SequenceHash>,
    },
    CloseSession {
        requester: InstanceId,
        session_id: SessionId,
    },
    G4Results {
        session_id: SessionId,
        found_hashes: Vec<(SequenceHash, usize)>,
    },
    G4LoadComplete {
        session_id: SessionId,
        success: Vec<SequenceHash>,
        failures: Vec<(SequenceHash, String)>,
        blocks: Arc<Vec<ImmutableBlock<G2>>>,
    },
}
Message types for session communication. Messages exchanged between leaders during onboarding sessions.

Phase 2 protocol (G2-only):

  1. Initiator sends CreateSession to multiple responders
  2. Each responder searches local G2 and sends G2Results back
  3. Initiator applies first-responder-wins and sends HoldBlocks to each
  4. Responders send Acknowledged after releasing unwanted blocks

Phase 3 protocol (G3 staging): 5. Responders search G3 and send G3Results 6. Initiator sends StageBlocks with blocks to stage G3->G2 7. Responders stage blocks and send BlocksReady when complete

Variants



CreateSession

Initiator creates a new onboarding session.

Fields

requester: InstanceId
session_id: SessionId
sequence_hashes: Vec<SequenceHash>


SearchComplete

Responder signals local search (G2 and G3) is complete.

Fields

responder: InstanceId
session_id: SessionId


G2Results

Responder reports G2 search results.

  • sequence_hashes: ordered list of matched sequence hashes
  • block_ids: parallel list of block IDs (can be zipped with sequence_hashes)

Fields

responder: InstanceId
session_id: SessionId
sequence_hashes: Vec<SequenceHash>
block_ids: Vec<BlockId>


G3Results

Responder reports G3 search results.

  • sequence_hashes: ordered list of matched sequence hashes (no block IDs)

Fields

responder: InstanceId
session_id: SessionId
sequence_hashes: Vec<SequenceHash>


HoldBlocks

Initiator tells responder which sequence hashes to hold/drop. Works across G2 and G3 tiers.

Fields

requester: InstanceId
session_id: SessionId
hold_hashes: Vec<SequenceHash>
drop_hashes: Vec<SequenceHash>


StageBlocks

Initiator tells responder which G3 sequence hashes to stage to G2. Any G3 blocks with these hashes should be staged to G2.

Fields

requester: InstanceId
session_id: SessionId
stage_hashes: Vec<SequenceHash>


BlocksReady

Responder reports newly staged blocks are ready in G2 (after G3->G2 staging). Only reports blocks that were just staged, not all G2 blocks.

  • sequence_hashes: newly staged blocks
  • block_ids: parallel to sequence_hashes

Fields

responder: InstanceId
session_id: SessionId
sequence_hashes: Vec<SequenceHash>
block_ids: Vec<BlockId>


Acknowledged

Responder acknowledges hold/drop request.

Fields

responder: InstanceId
session_id: SessionId


ReleaseBlocks

Initiator tells responder to release specific sequence hashes that weren’t selected. Works across G2 and G3 tiers.

Fields

requester: InstanceId
session_id: SessionId
release_hashes: Vec<SequenceHash>


CloseSession

Initiator tells responder session is complete, responder can cleanup.

Fields

requester: InstanceId
session_id: SessionId


G4Results

G4 search results from object storage has_blocks.

Internal message sent via mpsc channel from the G4 search task to the initiator session. Contains hashes found in object storage with their sizes.

Fields

session_id: SessionId
found_hashes: Vec<(SequenceHash, usize)>

Hashes found in G4 with their sizes in bytes



G4LoadComplete

G4 load completion results from object storage get_blocks.

Internal message sent via mpsc channel from the G4 load task to the initiator session. Contains per-block success/failure.

Fields

session_id: SessionId
success: Vec<SequenceHash>

Successfully loaded hashes

failures: Vec<(SequenceHash, String)>

Failed hashes with error messages

blocks: Arc<Vec<ImmutableBlock<G2>>>

Successfully loaded and registered G2 blocks. These are ready to be added to local_g2_blocks. Wrapped in Arc for Clone derivation (internal message only).

Implementations

Source

impl OnboardMessage

pub fn session_id(&self) -> SessionId

Extract the session ID from any message variant.

pub fn instance_id(&self) -> InstanceId

Extract the requester/responder instance ID from the message.

Panics

Panics if called on G4 messages (internal only, no instance ID).

pub fn variant_name(&self) -> &'static str

Get the variant name as a string for logging.