pub struct AsyncSessionResult { /* private fields */ }Expand description
Async session result for staging and/or remote search operations.
Implementations
Sourceimpl AsyncSessionResult
impl AsyncSessionResult
Sourcepub fn new(
session_id: SessionId,
status_rx: Receiver<OnboardingStatus>,
blocks: Arc<Mutex<Option<Vec<ImmutableBlock<G2>>>>>,
session_handle: Option<SessionHandle>,
) -> Self
pub fn new( session_id: SessionId, status_rx: Receiver<OnboardingStatus>, blocks: Arc<Mutex<Option<Vec<ImmutableBlock<G2>>>>>, session_handle: Option<SessionHandle>, ) -> Self
Create a new async session result.
Sourcepub fn session_id(&self) -> SessionId
pub fn session_id(&self) -> SessionId
Get the session ID for this onboarding operation.
Sourcepub fn status(&self) -> OnboardingStatus
pub fn status(&self) -> OnboardingStatus
Get the current status of the onboarding operation.
Sourcepub fn session_handle(&self) -> Option<&SessionHandle>
pub fn session_handle(&self) -> Option<&SessionHandle>
Get session handle for deferred operations (Hold/Prepare modes only).
Returns None for StagingMode::Full.
Sourcepub fn get_blocks_count(&self) -> Option<usize>
pub fn get_blocks_count(&self) -> Option<usize>
Non-blocking check if blocks are available.
Returns Some(count) if blocks are available, None if still in progress. Use wait_for_completion() to take ownership of blocks.
Sourcepub fn wait_for_completion(&self) -> BoxFuture<'static, Result<()>>
pub fn wait_for_completion(&self) -> BoxFuture<'static, Result<()>>
Wait for the operation to complete and return the matched blocks.
For StagingMode::Full, waits for Complete status. For Hold/Prepare modes, waits for terminal state (Holding/Prepared/Complete).
This method returns a future that can be used with tokio::select!.