create_key_formatter

Function create_key_formatter 

pub fn create_key_formatter(rank: Option<usize>) -> Arc<dyn KeyFormatter> 
Create a key formatter appropriate for the given rank.

Returns a RankPrefixedKeyFormatter if rank is provided, otherwise returns a DefaultKeyFormatter.