Module s3

Module s3 

S3-compatible object storage implementations.

This module contains all S3-specific implementations:

All types in this module are feature-gated behind s3. Consumers should use the factory functions in the parent object module to create trait objects without needing to depend on the s3 feature.

Structs

S3Config
Configuration for S3 object storage client.
S3LockManager
S3-based implementation of ObjectLockManager.
S3ObjectBlockClient
S3-compatible object storage client for block operations.