LayoutConfigExt

Trait LayoutConfigExt 

pub trait LayoutConfigExt {
    // Required methods
    fn block_size_bytes(&self) -> usize;
    fn region_size(&self) -> usize;
}
Extension methods for LayoutConfig to support object storage operations.

Required Methods

fn block_size_bytes(&self) -> usize

Compute the size of a single block in bytes.

fn region_size(&self) -> usize

Compute the size of a single memory region in bytes.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl LayoutConfigExt for LayoutConfig

Implementors