pub struct ExternalBlock<T: BlockMetadata> {
pub block_id: BlockId,
pub sequence_hash: SequenceHash,
/* private fields */
}Expand description
External block reference with sequence hash for registration.
Used when the caller holds the actual block but wants to provide the offload engine with enough information to register blocks in the destination tier after transfer.
Fields
block_id: BlockIdThe block ID in the source tier
sequence_hash: SequenceHashThe sequence hash for registration in destination tier
Implementations
Sourceimpl<T: BlockMetadata> ExternalBlock<T>
impl<T: BlockMetadata> ExternalBlock<T>
Sourcepub fn new(block_id: BlockId, sequence_hash: SequenceHash) -> Self
pub fn new(block_id: BlockId, sequence_hash: SequenceHash) -> Self
Create a new external block reference.