pub struct TransferHandle { /* private fields */ }Expand description
Handle for tracking and controlling an offload transfer.
Obtained from OffloadEngine::enqueue(). Use this to:
- Monitor transfer progress via
status(),passed_blocks(), etc. - Cancel the transfer via
cancel()and await confirmation - Wait for completion via
wait()
Implementations
Sourceimpl TransferHandle
impl TransferHandle
Sourcepub fn id(&self) -> TransferId
pub fn id(&self) -> TransferId
Get the transfer ID.
Sourcepub fn status(&self) -> TransferStatus
pub fn status(&self) -> TransferStatus
Get the current transfer status.
Sourcepub fn passed_blocks(&self) -> Vec<BlockId> ⓘ
pub fn passed_blocks(&self) -> Vec<BlockId> ⓘ
Get blocks that passed all filter policies.
Sourcepub fn completed_blocks(&self) -> Vec<BlockId> ⓘ
pub fn completed_blocks(&self) -> Vec<BlockId> ⓘ
Get blocks that have been successfully transferred.
Sourcepub fn failed_blocks(&self) -> Vec<BlockId> ⓘ
pub fn failed_blocks(&self) -> Vec<BlockId> ⓘ
Get blocks that failed transfer.
Sourcepub fn remaining_blocks(&self) -> Vec<BlockId> ⓘ
pub fn remaining_blocks(&self) -> Vec<BlockId> ⓘ
Get blocks remaining to be transferred.
Sourcepub fn progress_counts(&self) -> TransferProgressCounts
pub fn progress_counts(&self) -> TransferProgressCounts
Return constant-size progress counts without cloning block vectors.
Sourcepub fn new_progress_cursor(&self) -> TransferProgressCursor
pub fn new_progress_cursor(&self) -> TransferProgressCursor
Create a cursor that consumes this transfer’s progress from the start.
Sourcepub fn consume_progress(
&self,
cursor: &mut TransferProgressCursor,
) -> TransferProgressDelta
pub fn consume_progress( &self, cursor: &mut TransferProgressCursor, ) -> TransferProgressDelta
Read each newly passed, completed, or failed block exactly once for this cursor, then advance the cursor to the current progress boundary.
Sourcepub fn is_complete(&self) -> bool
pub fn is_complete(&self) -> bool
Check if the transfer is complete (success, cancelled, or failed).
Sourcepub fn cancel(&self) -> CancelConfirmation
pub fn cancel(&self) -> CancelConfirmation
Sourcepub fn is_cancelled(&self) -> bool
pub fn is_cancelled(&self) -> bool
Check if cancellation has been requested.
Sourcepub async fn wait(&mut self) -> Result<TransferResult>
pub async fn wait(&mut self) -> Result<TransferResult>
Wait for the transfer to complete.
Returns the final TransferResult when the transfer reaches a terminal state.
Sourcepub fn subscribe_status(&self) -> Receiver<TransferStatus>
pub fn subscribe_status(&self) -> Receiver<TransferStatus>
Subscribe to status changes.
Sourcepub fn subscribe_progress(&self) -> Receiver<TransferProgressCounts>
pub fn subscribe_progress(&self) -> Receiver<TransferProgressCounts>
Subscribe to constant-size block progress counts.