pub struct LeaderLayoutConfig {
pub rank: usize,
pub host_block_count: usize,
pub disk_block_count: Option<usize>,
pub object: Option<ObjectConfig>,
pub parallelism: ParallelismMode,
}Expand description
Configuration sent from leader to workers for G2/G3/G4 layout creation.
This message is sent via Nova RPC during Phase 3 coordination. Workers use this to create additional cache tiers beyond G1 (GPU KV).
Fields
rank: usizeLeader provided rank of this worker
The Connector framework provides us with an ordered list of workers. To ensure leaders and workers are all in-sync on this information, the leader will send each worker the rank provided by the Connector framework.
host_block_count: usizeNumber of host/pinned blocks for G2 tier.
disk_block_count: Option<usize>Number of disk blocks for G3 tier (None = no disk tier).
object: Option<ObjectConfig>Object storage configuration for G4 tier (None = no object tier).
When present, workers should instantiate object clients for storing blocks in external object storage (S3/MinIO).
parallelism: ParallelismModeParallelism mode for this worker.
When ReplicatedData and rank > 0, the worker skips G2/G3 creation
since only rank 0 has host/disk storage in replicated mode.