pub enum LogicalLayoutHandle {
G1,
G2,
G3,
G4,
}Expand description
Logical layout handle type encoding the layout ID.
KVBM manages G1, G2 and G3 layouts directly. G4 is managed by an external service.
Variants
G1
Representation of GPU / Device Memory G1 is fixed sized and managed by either the framework or the local instance of KVBM.
G2
Representation of CPU / Host Memory G2 is fixed sized and managed by the local instance of KVBM.
G3
Representation of Disk Storage (Local or AttachedStorage) G3 is fixed sized and managed by the local instance of KVBM.
G4
Representation of Blocks held in an external service outside the control of the KVBM system.