pub trait LayoutConfigExt {
// Required methods
fn block_size_bytes(&self) -> usize;
fn region_size(&self) -> usize;
}Expand description
Extension methods for LayoutConfig to support object storage operations.
Required Methods
Sourcefn block_size_bytes(&self) -> usize
fn block_size_bytes(&self) -> usize
Compute the size of a single block in bytes.
Sourcefn region_size(&self) -> usize
fn region_size(&self) -> usize
Compute the size of a single memory region in bytes.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".