pub struct Pipeline<Src: BlockMetadata, Dst: BlockMetadata> { /* private fields */ }Expand description
A running pipeline instance.
Implementations
Sourceimpl<Src: BlockMetadata, Dst: BlockMetadata> Pipeline<Src, Dst>
impl<Src: BlockMetadata, Dst: BlockMetadata> Pipeline<Src, Dst>
Sourcepub fn new(
config: PipelineConfig<Src, Dst>,
_registry: Arc<BlockRegistry>,
dst_manager: Arc<BlockManager<Dst>>,
leader: Arc<InstanceLeader>,
src_layout: LogicalLayoutHandle,
dst_layout: LogicalLayoutHandle,
runtime: Handle,
) -> Self
pub fn new( config: PipelineConfig<Src, Dst>, _registry: Arc<BlockRegistry>, dst_manager: Arc<BlockManager<Dst>>, leader: Arc<InstanceLeader>, src_layout: LogicalLayoutHandle, dst_layout: LogicalLayoutHandle, runtime: Handle, ) -> Self
Create a new pipeline with the given configuration.
Arguments
config- Pipeline configurationregistry- Block registry for policy evaluationdst_manager- Destination tier block managerleader- Instance leader for transfer executionsrc_layout- Source logical layout handledst_layout- Destination logical layout handleruntime- Tokio runtime handle for spawning background tasks
Sourcepub fn request_cancel(&self, transfer_id: TransferId)
pub fn request_cancel(&self, transfer_id: TransferId)
Request cancellation for a transfer.
This marks the transfer as cancelled in all queues, triggering the sweeper to remove queued items and the evaluator/collector to skip them.
Sourcepub fn auto_chain(&self) -> bool
pub fn auto_chain(&self) -> bool
Check if this pipeline auto-chains to downstream.
Sourcepub fn output_tx(&self) -> Option<Sender<PipelineOutput>>
pub fn output_tx(&self) -> Option<Sender<PipelineOutput>>
Get a clone of the output channel sender.
Sourcepub fn take_chain_rx(&mut self) -> Option<Receiver<ChainOutput<Dst>>>
pub fn take_chain_rx(&mut self) -> Option<Receiver<ChainOutput<Dst>>>
Take the chain output receiver for downstream pipeline feeding.
This transfers ownership of the receiver - can only be called once.
When auto_chain is enabled, this receiver will yield ChainOutput<Dst>
containing registered blocks that can be fed to a downstream pipeline.
Returns
Some(rx)ifauto_chainis enabled and receiver hasn’t been takenNoneifauto_chainis false or receiver was already taken
Sourcepub fn pending_tracker(&self) -> &Arc<PendingTracker> ⓘ
pub fn pending_tracker(&self) -> &Arc<PendingTracker> ⓘ
Get the pending tracker for this pipeline.
This can be shared with presence policies to enable duplicate prevention for blocks currently in-flight through this pipeline.